@@ -1,4 +1,5 @@
 from datetime import datetime, timedelta
+from pathlib import Path
 import time
 import threading
 from typing import Dict
@@ -7,7 +8,7 @@ from pam.api import API
 from pam.service import Service
 from pam.models.request_command import RequestCommand
 from pam.interface_task_manager import ITaskManager
-
+from pam.temp_file_utils import TempfileUtils
 
 class ServiceHolder:
     def __init__(self, service: Service):
@@ -152,6 +153,77 @@ class TaskManager(ITaskManager):
         http_thread = threading.Thread(target=api_call_wrapper)
         http_thread.start()
 
+    def service_request_sqlite(self, service: Service, file_name="", is_shared=False):
+        """Requests last sqlite file that this plugin has uploaded from the last time.
+        Returns:
+            The file path to the downloaded SQLite file, or None if the download failed.
+        """
+    
+        log(f"{service.request.service_name}: Requesting sqlite for file_name={file_name}")
+        
+        endpoint = service.request.sqlite_download
+        token = service.request.token
+        json_data = {"file_name": file_name, "is_shared": is_shared, "token": token}
+
+        # Create a unique suffix using current datetime
+        timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
+        unique_file_name = f"{file_name or 'latest'}_{timestamp}"
+
+        # Create a temp file path for the downloaded .sqlite file
+        output_path = TempfileUtils.get_temp_file_name(
+            service.request.service_name,
+            token,
+            f"sqlite_{unique_file_name}_",
+            ".sqlite"
+        )
+
+        # Download SQLite file
+        success = self.api.download_sqlite_from_post(endpoint, json_data, output_path)
+
+        if success:
+            log(f"{service.request.service_name}: Successfully downloaded SQLite file to {output_path}")
+            return output_path
+        else:
+            log(f"{service.request.service_name}: Failed to download SQLite file.")
+            return output_path
+
+    def service_upload_sqlite(self, service: Service, file_name: str = "", is_shared: bool = False, sqlite_file: str = "") -> str:
+        """
+        Uploads the result SQLite file to CDP.
+
+        :param file_name: The logical file name being uploaded.
+        :param is_shared: Whether this file should be treated as shared.
+        :param sqlite_file: Path to the SQLite file to upload.
+        :return: The uploaded file name if successful, or empty string if failed.
+        """
+        if not sqlite_file:
+            log(f"{service.request.service_name}: No sqlite file provided for upload.")
+            return ""
+
+        if not Path(sqlite_file).is_file():
+            log(f"{service.request.service_name}: SQLite file does not exist: {sqlite_file}")
+            return ""
+
+        endpoint = service.request.sqlite_upload
+        payload = {
+            "file_name": file_name,
+            "is_shared": str(is_shared).lower(),  # form data values must be string
+            "token": service.request.token
+        }
+
+        try:
+            log(f"{service.request.service_name}: Uploading sqlite file: {sqlite_file} with payload: {payload}")
+            response = self.api.http_upload(endpoint, sqlite_file, payload)
+
+            if response and response.ok:
+                log(f"{service.request.service_name}: SQLite file uploaded successfully.")
+                return file_name or Path(sqlite_file).name
+            else:
+                log(f"{service.request.service_name}: Failed to upload sqlite. Status: {response.status_code if response else 'N/A'}")
+                return ""
+        except Exception as e:
+            log(f"{service.request.service_name}: Exception while uploading sqlite: {e}")
+            return ""
 
     def service_upload_result(self, service: Service, file_path):
         """
