@@ -23,6 +23,7 @@ class TesterTask(ITaskManager):
         self.upload_sqlite_callback: Optional[UploadSqliteCallbackType] = None
         self.upload_result_callback: Optional[UploadResultCallbackType] = None
         self.upload_report_callback: Optional[UploadReportCallbackType] = None
+        self.is_exit = False
 
     def set_on_request_data(self, request_data_callback: RequestDataCallbackType):
         """
@@ -73,8 +74,13 @@ class TesterTask(ITaskManager):
         pass
 
     def service_exit(self, service: Service):
+        self.is_exit = True
         print(f"{service.request.service_name} Exit.")
 
+    def wait_for_task_done(self):
+        while not self.is_exit:
+            pass
+
     def service_request_data(self, service: Service, page: str):
         """
         Simulate a service data request.
